From: Nilson Santos Figueiredo Junior <nilsonsfj@cpan.org>     
Date: Tue, 3 Jan 2006 21:05:43 -0300
To: INGY@cpan.org
Subject: About your YAML distribution
From acid06@gmail.com  Tue Jan  3 16:07:44 2006

Hello,

While reading the documentation for the current "official" release of
YAML (0.39) I noticed you mentioned the impossiblity of representing
structured keys using Perl's hash. I don't know if you already found a
solution (since in the current development release this notice isn't
there anymore) but, if you didn't, I think you should take a look at
the core module "Tie::RefHash" which seems to suit nicely YAML's
needs.

Best regards,

--
nilson

